import request from '@/utils/request'

// 查询设备BOM信息列表
export function listBom(query) {
  return request({
    url: '/dms/bom/list',
    method: 'get',
    params: query
  })
}

// 查询设备BOM信息详细
export function getBom(deviceBomId) {
  return request({
    url: '/dms/bom/' + deviceBomId,
    method: 'get'
  })
}

// 新增设备BOM信息
export function addBom(data) {
  return request({
    url: '/dms/bom',
    method: 'post',
    data: data
  })
}

// 修改设备BOM信息
export function updateBom(data) {
  return request({
    url: '/dms/bom',
    method: 'put',
    data: data
  })
}

// 删除设备BOM信息
export function delBom(deviceBomId) {
  return request({
    url: '/dms/bom/' + deviceBomId,
    method: 'delete'
  })
}

//连表查询 通过设备类型查询bom信息
export function selectBomByDeviceType(data) {
  return request({
    url: '/dms/bom/selectBomByDeviceType',
    method: 'post',
    data: data
  })
}


